@@ -25,7 +25,7 @@ class UserMixin:
     _users_following = {}  # user_pk -> dict(user_pk -> "short user object")
     _users_followers = {}  # user_pk -> dict(user_pk -> "short user object")
 
-    def user_id_from_username(self, username: str) -> int:
+    def user_id_from_username(self, username: str) -> str:
         """
         Get full media id
 
@@ -36,7 +36,7 @@ class UserMixin:
 
         Returns
         -------
-        int
+        str
             User PK
 
         Example
@@ -44,15 +44,15 @@ class UserMixin:
         'adw0rd' -> 1903424587
         """
         username = str(username).lower()
-        return int(self.user_info_by_username(username).pk)
+        return str(self.user_info_by_username(username).pk)
 
-    def user_short_gql(self, user_id: int, use_cache: bool = True) -> UserShort:
+    def user_short_gql(self, user_id: str, use_cache: bool = True) -> UserShort:
         """
         Get full media id
 
         Parameters
         ----------
-        user_id: int
+        user_id: str
             User ID
         use_cache: bool, optional
             Whether or not to use information from cache, default value is True
@@ -67,7 +67,7 @@ class UserMixin:
             if cache:
                 return cache
         variables = {
-            "user_id": int(user_id),
+            "user_id": str(user_id),
             "include_reel": True,
         }
         data = self.public_graphql_request(
@@ -79,13 +79,13 @@ class UserMixin:
         self._userhorts_cache[user_id] = user
         return user
 
-    def username_from_user_id_gql(self, user_id: int) -> str:
+    def username_from_user_id_gql(self, user_id: str) -> str:
         """
         Get username from user id
 
         Parameters
         ----------
-        user_id: int
+        user_id: str
             User ID
 
         Returns
@@ -99,13 +99,13 @@ class UserMixin:
         """
         return self.user_short_gql(user_id).username
 
-    def username_from_user_id(self, user_id: int) -> str:
+    def username_from_user_id(self, user_id: str) -> str:
         """
         Get username from user id
 
         Parameters
         ----------
-        user_id: int
+        user_id: str
             User ID
 
         Returns
@@ -117,7 +117,7 @@ class UserMixin:
         -------
         1903424587 -> 'adw0rd'
         """
-        user_id = int(user_id)
+        user_id = str(user_id)
         try:
             username = self.username_from_user_id_gql(user_id)
         except ClientError:
@@ -199,13 +199,13 @@ class UserMixin:
             self._usernames_cache[user.username] = user.pk
         return self.user_info(self._usernames_cache[username])
 
-    def user_info_gql(self, user_id: int) -> User:
+    def user_info_gql(self, user_id: str) -> User:
         """
         Get user object from user id
 
         Parameters
         ----------
-        user_id: int
+        user_id: str
             User id of an instagram account
 
         Returns
@@ -213,7 +213,7 @@ class UserMixin:
         User
             An object of User type
         """
-        user_id = int(user_id)
+        user_id = str(user_id)
         try:
             # GraphQL haven't method to receive user by id
             return self.user_info_by_username_gql(
@@ -222,13 +222,13 @@ class UserMixin:
         except JSONDecodeError as e:
             raise ClientJSONDecodeError(e, user_id=user_id)
 
-    def user_info_v1(self, user_id: int) -> User:
+    def user_info_v1(self, user_id: str) -> User:
         """
         Get user object from user id
 
         Parameters
         ----------
-        user_id: int
+        user_id: str
             User id of an instagram account
 
         Returns
@@ -236,7 +236,7 @@ class UserMixin:
         User
             An object of User type
         """
-        user_id = int(user_id)
+        user_id = str(user_id)
         try:
             result = self.private_request(f"users/{user_id}/info/")
         except ClientNotFoundError as e:
@@ -247,13 +247,13 @@ class UserMixin:
             raise e
         return extract_user_v1(result["user"])
 
-    def user_info(self, user_id: int, use_cache: bool = True) -> User:
+    def user_info(self, user_id: str, use_cache: bool = True) -> User:
         """
         Get user object from user id
 
         Parameters
         ----------
-        user_id: int
+        user_id: str
             User id of an instagram account
         use_cache: bool, optional
             Whether or not to use information from cache, default value is True
@@ -263,7 +263,7 @@ class UserMixin:
         User
             An object of User type
         """
-        user_id = int(user_id)
+        user_id = str(user_id)
         if not use_cache or user_id not in self._users_cache:
             try:
                 try:
@@ -294,13 +294,32 @@ class UserMixin:
         results = self.private_request("feed/new_feed_posts_exist/")
         return results.get("new_feed_posts_exist", False)
 
-    def user_friendship_v1(self, user_id: int) -> Relationship:
+    def user_friendships_v1(self, user_ids: List[str]) -> dict:
         """
         Get user friendship status
 
         Parameters
         ----------
-        user_id: int
+        user_ids: List[str]
+            List of user id of an instagram account
+
+        Returns
+        -------
+        dict
+        """
+        result = self.private_request(
+            "friendships/show_many/",
+            data={"user_ids": user_ids}
+        )
+        return result["friendship_statuses"]
+
+    def user_friendship_v1(self, user_id: str) -> Relationship:
+        """
+        Get user friendship status
+
+        Parameters
+        ----------
+        user_id: str
             User id of an instagram account
 
         Returns
@@ -316,13 +335,13 @@ class UserMixin:
             self.logger.exception(e)
             return None
 
-    def search_followers_v1(self, user_id: int, query: str) -> List[UserShort]:
+    def search_followers_v1(self, user_id: str, query: str) -> List[UserShort]:
         """
         Search users by followers (Private Mobile API)
 
         Parameters
         ----------
-        user_id: int
+        user_id: str
             User id of an instagram account
         query: str
             Query to search
@@ -343,13 +362,13 @@ class UserMixin:
         users = results.get("users", [])
         return [extract_user_short(user) for user in users]
 
-    def search_followers(self, user_id: int, query: str) -> List[UserShort]:
+    def search_followers(self, user_id: str, query: str) -> List[UserShort]:
         """
         Search by followers
 
         Parameters
         ----------
-        user_id: int
+        user_id: str
             User id of an instagram account
         query: str
             Query string
@@ -361,13 +380,13 @@ class UserMixin:
         """
         return self.search_followers_v1(user_id, query)
 
-    def search_following_v1(self, user_id: int, query: str) -> List[UserShort]:
+    def search_following_v1(self, user_id: str, query: str) -> List[UserShort]:
         """
         Search following users (Private Mobile API)
 
         Parameters
         ----------
-        user_id: int
+        user_id: str
             User id of an instagram account
         query: str
             Query to search
@@ -389,13 +408,13 @@ class UserMixin:
         users = results.get("users", [])
         return [extract_user_short(user) for user in users]
 
-    def search_following(self, user_id: int, query: str) -> List[UserShort]:
+    def search_following(self, user_id: str, query: str) -> List[UserShort]:
         """
         Search by following
 
         Parameters
         ----------
-        user_id: int
+        user_id: str
             User id of an instagram account
         query: str
             Query string
@@ -407,13 +426,13 @@ class UserMixin:
         """
         return self.search_following_v1(user_id, query)
 
-    def user_following_gql(self, user_id: int, amount: int = 0) -> List[UserShort]:
+    def user_following_gql(self, user_id: str, amount: int = 0) -> List[UserShort]:
         """
         Get user's following information by Public Graphql API
 
         Parameters
         ----------
-        user_id: int
+        user_id: str
             User id of an instagram account
         amount: int, optional
             Maximum number of media to return, default is 0
@@ -423,7 +442,7 @@ class UserMixin:
         List[UserShort]
             List of objects of User type
         """
-        user_id = int(user_id)
+        user_id = str(user_id)
         end_cursor = None
         users = []
         variables = {
@@ -455,13 +474,13 @@ class UserMixin:
             users = users[:amount]
         return users
 
-    def user_following_v1(self, user_id: int, amount: int = 0) -> List[UserShort]:
+    def user_following_v1(self, user_id: str, amount: int = 0) -> List[UserShort]:
         """
         Get user's following users information by Private Mobile API
 
         Parameters
         ----------
-        user_id: int
+        user_id: str
             User id of an instagram account
         amount: int, optional
             Maximum number of media to return, default is 0
@@ -471,7 +490,7 @@ class UserMixin:
         List[UserShort]
             List of objects of User type
         """
-        user_id = int(user_id)
+        user_id = str(user_id)
         max_id = ""
         users = []
         while True:
@@ -498,14 +517,14 @@ class UserMixin:
         return users
 
     def user_following(
-        self, user_id: int, use_cache: bool = True, amount: int = 0
-    ) -> Dict[int, UserShort]:
+        self, user_id: str, use_cache: bool = True, amount: int = 0
+    ) -> Dict[str, UserShort]:
         """
         Get user's followers information
 
         Parameters
         ----------
-        user_id: int
+        user_id: str
             User id of an instagram account
         use_cache: bool, optional
             Whether or not to use information from cache, default value is True
@@ -514,10 +533,10 @@ class UserMixin:
 
         Returns
         -------
-        Dict[int, UserShort]
+        Dict[str, UserShort]
             Dict of user_id and User object
         """
-        user_id = int(user_id)
+        user_id = str(user_id)
         users = self._users_following.get(user_id, {})
         if not use_cache or not users or (amount and len(users) < amount):
             # Temporary: Instagram Required Login for GQL request
@@ -535,13 +554,13 @@ class UserMixin:
             following = dict(list(following.items())[:amount])
         return following
 
-    def user_followers_gql_chunk(self, user_id: int, max_amount: int = 0, end_cursor: str = None) -> Tuple[List[UserShort], str]:
+    def user_followers_gql_chunk(self, user_id: str, max_amount: int = 0, end_cursor: str = None) -> Tuple[List[UserShort], str]:
         """
         Get user's followers information by Public Graphql API and end_cursor
 
         Parameters
         ----------
-        user_id: int
+        user_id: str
             User id of an instagram account
         max_amount: int, optional
             Maximum number of media to return, default is 0 - Inf
@@ -553,7 +572,7 @@ class UserMixin:
         Tuple[List[UserShort], str]
             List of objects of User type with cursor
         """
-        user_id = int(user_id)
+        user_id = str(user_id)
         users = []
         variables = {
             "id": user_id,
@@ -581,13 +600,13 @@ class UserMixin:
                 break
         return users, end_cursor
 
-    def user_followers_gql(self, user_id: int, amount: int = 0) -> List[UserShort]:
+    def user_followers_gql(self, user_id: str, amount: int = 0) -> List[UserShort]:
         """
         Get user's followers information by Public Graphql API
 
         Parameters
         ----------
-        user_id: int
+        user_id: str
             User id of an instagram account
         amount: int, optional
             Maximum number of media to return, default is 0 - Inf
@@ -597,18 +616,18 @@ class UserMixin:
         List[UserShort]
             List of objects of User type
         """
-        users, _ = self.user_followers_gql_chunk(int(user_id), amount)
+        users, _ = self.user_followers_gql_chunk(str(user_id), amount)
         if amount:
             users = users[:amount]
         return users
 
-    def user_followers_v1_chunk(self, user_id: int, max_amount: int = 0, max_id: str = "") -> Tuple[List[UserShort], str]:
+    def user_followers_v1_chunk(self, user_id: str, max_amount: int = 0, max_id: str = "") -> Tuple[List[UserShort], str]:
         """
         Get user's followers information by Private Mobile API and max_id (cursor)
 
         Parameters
         ----------
-        user_id: int
+        user_id: str
             User id of an instagram account
         max_amount: int, optional
             Maximum number of media to return, default is 0 - Inf
@@ -642,13 +661,13 @@ class UserMixin:
                 break
         return users, max_id
 
-    def user_followers_v1(self, user_id: int, amount: int = 0) -> List[UserShort]:
+    def user_followers_v1(self, user_id: str, amount: int = 0) -> List[UserShort]:
         """
         Get user's followers information by Private Mobile API
 
         Parameters
         ----------
-        user_id: int
+        user_id: str
             User id of an instagram account
         amount: int, optional
             Maximum number of media to return, default is 0 - Inf
@@ -658,20 +677,20 @@ class UserMixin:
         List[UserShort]
             List of objects of User type
         """
-        users, _ = self.user_followers_v1_chunk(int(user_id), amount)
+        users, _ = self.user_followers_v1_chunk(str(user_id), amount)
         if amount:
             users = users[:amount]
         return users
 
     def user_followers(
-        self, user_id: int, use_cache: bool = True, amount: int = 0
-    ) -> Dict[int, UserShort]:
+        self, user_id: str, use_cache: bool = True, amount: int = 0
+    ) -> Dict[str, UserShort]:
         """
         Get user's followers
 
         Parameters
         ----------
-        user_id: int
+        user_id: str
             User id of an instagram account
         use_cache: bool, optional
             Whether or not to use information from cache, default value is True
@@ -680,10 +699,10 @@ class UserMixin:
 
         Returns
         -------
-        Dict[int, UserShort]
+        Dict[str, UserShort]
             Dict of user_id and User object
         """
-        user_id = int(user_id)
+        user_id = str(user_id)
         users = self._users_followers.get(user_id, {})
         if not use_cache or not users or (amount and len(users) < amount):
             try:
@@ -698,13 +717,13 @@ class UserMixin:
             followers = dict(list(followers.items())[:amount])
         return followers
 
-    def user_follow(self, user_id: int) -> bool:
+    def user_follow(self, user_id: str) -> bool:
         """
         Follow a user
 
         Parameters
         ----------
-        user_id: int
+        user_id: str
 
         Returns
         -------
@@ -712,7 +731,7 @@ class UserMixin:
             A boolean value
         """
         assert self.user_id, "Login required"
-        user_id = int(user_id)
+        user_id = str(user_id)
         if user_id in self._users_following.get(self.user_id, []):
             self.logger.debug("User %s already followed", user_id)
             return False
@@ -722,13 +741,13 @@ class UserMixin:
             self._users_following.pop(self.user_id)  # reset
         return result["friendship_status"]["following"] is True
 
-    def user_unfollow(self, user_id: int) -> bool:
+    def user_unfollow(self, user_id: str) -> bool:
         """
         Unfollow a user
 
         Parameters
         ----------
-        user_id: int
+        user_id: str
 
         Returns
         -------
@@ -736,20 +755,20 @@ class UserMixin:
             A boolean value
         """
         assert self.user_id, "Login required"
-        user_id = int(user_id)
+        user_id = str(user_id)
         data = self.with_action_data({"user_id": user_id})
         result = self.private_request(f"friendships/destroy/{user_id}/", data)
         if self.user_id in self._users_following:
             self._users_following[self.user_id].pop(user_id, None)
         return result["friendship_status"]["following"] is False
 
-    def user_remove_follower(self, user_id: int) -> bool:
+    def user_remove_follower(self, user_id: str) -> bool:
         """
         Remove a follower
 
         Parameters
         ----------
-        user_id: int
+        user_id: str
 
         Returns
         -------
@@ -757,20 +776,20 @@ class UserMixin:
             A boolean value
         """
         assert self.user_id, "Login required"
-        user_id = int(user_id)
+        user_id = str(user_id)
         data = self.with_action_data({"user_id": str(user_id)})
         result = self.private_request(f"friendships/remove_follower/{user_id}/", data)
         if self.user_id in self._users_followers:
             self._users_followers[self.user_id].pop(user_id, None)
         return result["friendship_status"]["followed_by"] is False
 
-    def mute_posts_from_follow(self, user_id: int, revert: bool = False) -> bool:
+    def mute_posts_from_follow(self, user_id: str, revert: bool = False) -> bool:
         """
         Mute posts from following user
 
         Parameters
         ----------
-        user_id: int
+        user_id: str
             Unique identifier of a User
         revert: bool, optional
             Unmute when True
@@ -780,7 +799,7 @@ class UserMixin:
         bool
             A boolean value
         """
-        user_id = int(user_id)
+        user_id = str(user_id)
         name = "unmute" if revert else "mute"
         result = self.private_request(
             f"friendships/{name}_posts_or_story_from_follow/",
@@ -792,13 +811,13 @@ class UserMixin:
         )
         return result["status"] == "ok"
 
-    def unmute_posts_from_follow(self, user_id: int) -> bool:
+    def unmute_posts_from_follow(self, user_id: str) -> bool:
         """
         Unmute posts from following user
 
         Parameters
         ----------
-        user_id: int
+        user_id: str
             Unique identifier of a User
 
         Returns
@@ -808,13 +827,13 @@ class UserMixin:
         """
         return self.mute_posts_from_follow(user_id, True)
 
-    def mute_stories_from_follow(self, user_id: int, revert: bool = False) -> bool:
+    def mute_stories_from_follow(self, user_id: str, revert: bool = False) -> bool:
         """
         Mute stories from following user
 
         Parameters
         ----------
-        user_id: int
+        user_id: str
             Unique identifier of a User
         revert: bool, optional
             Unmute when True
@@ -824,7 +843,7 @@ class UserMixin:
         bool
             A boolean value
         """
-        user_id = int(user_id)
+        user_id = str(user_id)
         name = "unmute" if revert else "mute"
         result = self.private_request(
             f"friendships/{name}_posts_or_story_from_follow/",
@@ -836,13 +855,13 @@ class UserMixin:
         )
         return result["status"] == "ok"
 
-    def unmute_stories_from_follow(self, user_id: int) -> bool:
+    def unmute_stories_from_follow(self, user_id: str) -> bool:
         """
         Unmute stories from following user
 
         Parameters
         ----------
-        user_id: int
+        user_id: str
             Unique identifier of a User
 
         Returns
